@@ -10,7 +10,7 @@ def section(context, section_name):
         data = context['infos'][section_name].items()
     except KeyError as e:
         accepted = ",".join(context['infos'].keys())
-        raise KeyError("{0}: ({1})".format(e, accepted))
+        raise KeyError("Section `{0}` not found in ({1})".format(e, accepted))
     name = section_name.lower()
 
     ctx = {
